@@ -86,11 +86,12 @@ int AlphabetTools::getType(char state)
 
 /**********************************************************************************************/
 
-bool AlphabetTools::checkAlphabetCodingSize(const Alphabet& alphabet) throw (AlphabetException)
+bool AlphabetTools::checkAlphabetCodingSize(const Alphabet& alphabet)
 {
   if (alphabet.getNumberOfChars() == 0)
     return true;  // Will this really happen?
   size_t size = alphabet.intToChar(0).size();
+
   for (int i = 1; i < static_cast<int>(alphabet.getNumberOfTypes()); ++i)
   {
     if (alphabet.intToChar(i).size() != size)
@@ -101,14 +102,14 @@ bool AlphabetTools::checkAlphabetCodingSize(const Alphabet& alphabet) throw (Alp
 
 /**********************************************************************************************/
 
-bool AlphabetTools::checkAlphabetCodingSize(const Alphabet* alphabet) throw (AlphabetException)
+bool AlphabetTools::checkAlphabetCodingSize(const Alphabet* alphabet)
 {
   return checkAlphabetCodingSize(*alphabet);
 }
 
 /**********************************************************************************************/
 
-unsigned int AlphabetTools::getAlphabetCodingSize(const Alphabet& alphabet) throw (AlphabetException)
+unsigned int AlphabetTools::getAlphabetCodingSize(const Alphabet& alphabet)
 {
   if (!checkAlphabetCodingSize(alphabet))
     throw AlphabetException("Bad alphabet in function Alphabet::getAlphabetCodingSize().");
@@ -117,7 +118,7 @@ unsigned int AlphabetTools::getAlphabetCodingSize(const Alphabet& alphabet) thro
 
 /**********************************************************************************************/
 
-unsigned int AlphabetTools::getAlphabetCodingSize(const Alphabet* alphabet) throw (AlphabetException)
+unsigned int AlphabetTools::getAlphabetCodingSize(const Alphabet* alphabet)
 {
   return getAlphabetCodingSize(*alphabet);
 }
