@@ -45,6 +45,7 @@
 #include "ProteicAlphabet.h"
 #include "DefaultAlphabet.h"
 #include "CodonAlphabet.h"
+#include "WordAlphabet.h"
 #include "RNY.h"
 #include "BinaryAlphabet.h"
 #include <Bpp/Numeric/VectorTools.h>
@@ -100,7 +101,7 @@ public:
    * @param alphabet The alphabet to check.
    * @return True if all text description have the same length (e.g. 3 for codon alphabet).
    */
-  static bool checkAlphabetCodingSize(const Alphabet& alphabet) throw (AlphabetException);
+  static bool checkAlphabetCodingSize(const Alphabet& alphabet);
 
   /**
    * @brief This checks that all characters in the alphabet are coded by a string of same length.
@@ -111,7 +112,7 @@ public:
    * @param alphabet a pointer toward the alphabet to check.
    * @return True if all text description have the same length (e.g. 3 for codon alphabet).
    */
-  static bool checkAlphabetCodingSize(const Alphabet* alphabet) throw (AlphabetException);
+  static bool checkAlphabetCodingSize(const Alphabet* alphabet);
 
   /**
    * @brief In case that all states in the given alphabet have a string description of same length,
@@ -120,7 +121,7 @@ public:
    * @param alphabet The alphabet to analyse.
    * @return The common size of all text descriptionif there is one. Else throws an AlphabetException.
    */
-  static unsigned int getAlphabetCodingSize(const Alphabet& alphabet) throw (AlphabetException);
+  static unsigned int getAlphabetCodingSize(const Alphabet& alphabet);
 
   /**
    * @brief In case that all states in the given alphabet have a string description of same length,
@@ -132,7 +133,7 @@ public:
    * @param alphabet a pointer toward the alphabet to analyse.
    * @return The common size of all text descriptionif there is one. Else throws an AlphabetException.
    */
-  static unsigned int getAlphabetCodingSize(const Alphabet* alphabet) throw (AlphabetException);
+  static unsigned int getAlphabetCodingSize(const Alphabet* alphabet);
 
   /**
    * @return True if the alphabet is an instanciation of the NucleicAlphabet class.
@@ -168,7 +169,7 @@ public:
    * @return True if the alphabet is an instanciation of the WordAlphabet class.
    * @param alphabet The alphabet to check.
    */
-  static bool isWordAlphabet(const Alphabet* alphabet) { return alphabetInheritsFrom<WordAlphabet>(alphabet); }
+  static bool isWordAlphabet(const Alphabet* alphabet) { return alphabetInheritsFrom<CoreWordAlphabet>(alphabet); }
 
   /**
    * @return True if the alphabet is an instanciation of the RNY class.
@@ -221,7 +222,7 @@ private:
     try
     {
       const Y* t = dynamic_cast<const Y*>(alphabet);
-      return t != 0; // Solves strange behavior in new gcc?
+      return t != nullptr;
     }
     catch (std::exception& e)
     {
