@@ -84,7 +84,7 @@ RNA::RNA(bool exclamationMarkCountsAsGap)
 
 /******************************************************************************/
 
-std::vector<int> RNA::getAlias(int state) const throw (BadIntException) 
+std::vector<int> RNA::getAlias(int state) const 
 {
 	if (!isIntInAlphabet(state))
     throw BadIntException(state, "DNA::getAlias(int): Specified base unknown.");
@@ -106,7 +106,7 @@ std::vector<int> RNA::getAlias(int state) const throw (BadIntException)
 
 /******************************************************************************/
 
-std::vector<std::string> RNA::getAlias(const std::string & state) const throw (BadCharException) 
+std::vector<std::string> RNA::getAlias(const std::string & state) const 
 {
   string locstate = TextTools::toUpper(state);
 	if(!isCharInAlphabet(locstate)) throw BadCharException(locstate, "RNA::getAlias(int): Specified base unknown.");
@@ -119,7 +119,7 @@ std::vector<std::string> RNA::getAlias(const std::string & state) const throw (B
 
 /******************************************************************************/
 
-int RNA::getGeneric(const std::vector<int> & states) const throw (BadIntException)
+int RNA::getGeneric(const std::vector<int> & states) const
 {
   int v = 0;
   for (size_t i = 0 ; i < states.size() ; ++i) {
@@ -131,7 +131,7 @@ int RNA::getGeneric(const std::vector<int> & states) const throw (BadIntExceptio
 
 /******************************************************************************/
 
-std::string RNA::getGeneric(const std::vector<std::string> & states) const throw (BadCharException)
+std::string RNA::getGeneric(const std::vector<std::string> & states) const
 {
   vector<int> vi;
   for (unsigned int i = 0 ; i < states.size() ; ++i) {
