@@ -69,7 +69,7 @@ class OrderedSequenceContainer:
 		 * @return A string describing the content of the sequence.
 		 * @throw IndexOutOfBoundsException If the position does not match any sequence in the container.
 		 */
-		virtual std::string toString(size_t sequenceIndex) const throw (IndexOutOfBoundsException) = 0;
+		virtual std::string toString(size_t sequenceIndex) const = 0;
 
 		/**
 		 * @brief Retrieve a sequence object from the container.
@@ -79,7 +79,7 @@ class OrderedSequenceContainer:
 		 * @return A reference toward the Sequence object with corresponding name.
 		 * @throw IndexOutOfBoundsException If the position does not match any sequence in the container.
 		 */
-		virtual const Sequence& getSequence(size_t sequenceIndex) const throw (IndexOutOfBoundsException) = 0;
+		virtual const Sequence& getSequence(size_t sequenceIndex) const = 0;
 
 		/**
 		 * @brief Replace a sequence in the container.
@@ -91,7 +91,7 @@ class OrderedSequenceContainer:
 		 * @throw IndexOutOfBoundsException If the position does not match any sequence in the container.
 		 * @throw Exception Any other kind of exception.
 		 */
-		virtual void setSequence(size_t sequenceIndex, const Sequence& sequence, bool checkName) throw (Exception) = 0;
+		virtual void setSequence(size_t sequenceIndex, const Sequence& sequence, bool checkName) = 0;
 
 		/**
 		 * @brief Extract (and remove) a sequence from the container.
@@ -100,7 +100,7 @@ class OrderedSequenceContainer:
 		 * @throw IndexOutOfBoundsException If the name does not match any sequence in
 		 * the container.
 		 */
-		virtual Sequence* removeSequence(size_t sequenceIndex) throw (IndexOutOfBoundsException, Exception) = 0;
+		virtual Sequence* removeSequence(size_t sequenceIndex) = 0;
 
 		/**
 		 * @brief Delete a sequence of the container.
@@ -109,7 +109,7 @@ class OrderedSequenceContainer:
 		 * @throw IndexOutOfBoundsException If the position does not match any sequence in
 		 * the container.
 		 */
-		virtual void deleteSequence(size_t sequenceIndex) throw (IndexOutOfBoundsException, Exception) = 0;
+		virtual void deleteSequence(size_t sequenceIndex) = 0;
 
 		/**
 		 * @brief Get the name of a particular sequence.
@@ -119,7 +119,7 @@ class OrderedSequenceContainer:
 		 * @throw IndexOutOfBoundsException If the position does not match any sequence in
 		 * the container.
 		 */
-		virtual const std::string& getName(size_t sequenceIndex) const throw (IndexOutOfBoundsException) = 0;
+		virtual const std::string& getName(size_t sequenceIndex) const = 0;
 
 		/**
 		 * @brief Get comments of a particular sequence.
@@ -129,7 +129,7 @@ class OrderedSequenceContainer:
 		 * @throw IndexOutOfBoundsException If the position does not match any sequence in
 		 * the container.
 		 */
-		virtual const Comments& getComments(size_t sequenceIndex) const throw (IndexOutOfBoundsException) = 0;
+		virtual const Comments& getComments(size_t sequenceIndex) const = 0;
 
 		/**
 		 * @brief Set the comments of a particular sequence.
@@ -139,7 +139,7 @@ class OrderedSequenceContainer:
 		 * @throw IndexOutOfBoundsException If the position does not match any sequence in
 		 * the container.
 		 */
-		virtual void setComments(size_t sequenceIndex, const Comments & comments) throw (IndexOutOfBoundsException) = 0;
+		virtual void setComments(size_t sequenceIndex, const Comments & comments) = 0;
 		
 		/**
 		 * @brief Get the position of a sequence in sequence container from its name.
@@ -148,7 +148,7 @@ class OrderedSequenceContainer:
 		 * @return The position of the sequence with name 'name', if it exists.
 		 * @throw SequenceNotFoundException If no sequence with name 'name' could be found.
 		 */
-		virtual size_t getSequencePosition(const std::string & name) const throw (SequenceNotFoundException) = 0;
+		virtual size_t getSequencePosition(const std::string & name) const = 0;
 
     /**
      * @name Provide direct access to sequences content.
@@ -160,9 +160,9 @@ class OrderedSequenceContainer:
      * @{
      */
 
-    virtual int& valueAt(const std::string& sequenceName, size_t elementIndex) throw (SequenceNotFoundException, IndexOutOfBoundsException) = 0;
+    virtual int& valueAt(const std::string& sequenceName, size_t elementIndex) = 0;
 
-    virtual const int& valueAt(const std::string& sequenceName, size_t elementIndex) const throw (SequenceNotFoundException, IndexOutOfBoundsException) = 0;
+    virtual const int& valueAt(const std::string& sequenceName, size_t elementIndex) const = 0;
 
     /**
      * @brief Element access operator.
@@ -173,7 +173,7 @@ class OrderedSequenceContainer:
      * @param elementIndex The element position within the sequence.
      * @throw IndexOutOfBoundsException If a position is not valid.
      */
-    virtual int& valueAt(size_t sequenceIndex, size_t elementIndex) throw (IndexOutOfBoundsException) = 0;
+    virtual int& valueAt(size_t sequenceIndex, size_t elementIndex) = 0;
     
     /**
      * @brief Element access operator.
@@ -184,7 +184,7 @@ class OrderedSequenceContainer:
      * @param elementIndex The element position within the sequence.
      * @throw IndexOutOfBoundsException If a position is not valid.
      */
-    virtual const int& valueAt(size_t sequenceIndex, size_t elementIndex) const throw (IndexOutOfBoundsException) = 0;
+    virtual const int& valueAt(size_t sequenceIndex, size_t elementIndex) const = 0;
 
     /**
      * @brief Element access operator.
@@ -218,16 +218,16 @@ class OrderedSequenceContainer:
 		 *
 		 * @{
 		 */
-		virtual std::string toString(const std::string& name) const throw (SequenceNotFoundException) = 0;  
-		virtual const Sequence& getSequence(const std::string& name) const throw (SequenceNotFoundException) = 0;
-		virtual void setSequence(const std::string& name, const Sequence& sequence, bool checkName) throw (Exception) = 0;
-		virtual Sequence* removeSequence(const std::string& name) throw (SequenceNotFoundException, Exception) = 0;
-		virtual void deleteSequence(const std::string& name) throw (SequenceNotFoundException, Exception) = 0;
+		virtual std::string toString(const std::string& name) const = 0;  
+		virtual const Sequence& getSequence(const std::string& name) const = 0;
+		virtual void setSequence(const std::string& name, const Sequence& sequence, bool checkName) = 0;
+		virtual Sequence* removeSequence(const std::string& name) = 0;
+		virtual void deleteSequence(const std::string& name) = 0;
 		virtual size_t getNumberOfSequences() const = 0;
 		virtual std::vector<std::string> getSequencesNames() const = 0;
-		virtual void setSequencesNames(const std::vector<std::string> & names, bool checkNames) throw (Exception) = 0;
-		virtual const Comments& getComments(const std::string& name) const throw (SequenceNotFoundException) = 0;
-		virtual void setComments(const std::string& name, const Comments& comments) throw (SequenceNotFoundException) = 0;
+		virtual void setSequencesNames(const std::vector<std::string> & names, bool checkNames) = 0;
+		virtual const Comments& getComments(const std::string& name) const = 0;
+		virtual void setComments(const std::string& name, const Comments& comments) = 0;
 		/** @} */
 };
 
