@@ -99,7 +99,7 @@ class SequenceContainer:
 		 * @return A string describing the content of the sequence.
 		 * @throw SequenceNotFoundException If the name does not match any sequence in the container.
 		 */
-		virtual std::string toString(const std::string& name) const throw (SequenceNotFoundException) = 0;  
+		virtual std::string toString(const std::string& name) const = 0;  
 
 		/**
 		 * @brief Retrieve a sequence object from the container.
@@ -108,7 +108,7 @@ class SequenceContainer:
 		 * @return A reference toward the Sequence with corresponding name.
 		 * @throw SequenceNotFoundException If the name does not match any sequence in the container.
 		 */
-		virtual const Sequence& getSequence(const std::string& name) const throw (SequenceNotFoundException) = 0;
+		virtual const Sequence& getSequence(const std::string& name) const = 0;
 
 		/**
 		 * @brief Check if a sequence with a given name is present in the container.
@@ -127,7 +127,7 @@ class SequenceContainer:
 		 * @throw Exception Any other kind of exception, if the name of the sequence is
 		 * already used, are whatever else depending on the implementation.
 		 */
-		virtual void addSequence(const Sequence& sequence, bool checkName) throw (Exception) = 0;
+		virtual void addSequence(const Sequence& sequence, bool checkName) = 0;
 
 		/**
 		 * @brief Replace a sequence in the container.
@@ -141,7 +141,7 @@ class SequenceContainer:
 		 * @throw Exception Any other kind of exception, if the name of the sequence is
 		 * already used, are whatever else depending on the implementation.
 		 */
-		virtual void setSequence(const std::string& name, const Sequence& sequence, bool checkName) throw (Exception) = 0;
+		virtual void setSequence(const std::string& name, const Sequence& sequence, bool checkName) = 0;
 
 		/**
 		 * @brief Extract (and remove) a sequence from the container.
@@ -150,7 +150,7 @@ class SequenceContainer:
 		 * @throw SequenceNotFoundException If the name does not match any sequence in
 		 * the container.
 		 */
-		virtual Sequence* removeSequence(const std::string& name) throw (SequenceNotFoundException, Exception) = 0;
+		virtual Sequence* removeSequence(const std::string& name) = 0;
 		
 		/**
 		 * @brief Delete a sequence of the container.
@@ -159,7 +159,7 @@ class SequenceContainer:
 		 * @throw SequenceNotFoundException If the name does not match any sequence in
 		 * the container.
 		 */
-		virtual void deleteSequence(const std::string& name) throw (SequenceNotFoundException, Exception) = 0;
+		virtual void deleteSequence(const std::string& name) = 0;
 
 		/**
 		 * @brief Get the number of sequences in the container.
@@ -185,7 +185,7 @@ class SequenceContainer:
 		 * is already used in the container before adding it.
 		 * @throw Exception If there are redundant names in the input vector.
 		 */
-		virtual void setSequencesNames(const std::vector<std::string>& names, bool checkNames) throw (Exception) = 0;
+		virtual void setSequencesNames(const std::vector<std::string>& names, bool checkNames) = 0;
 
 		/**
 		 * @brief Get comments of a particular sequence.
@@ -195,7 +195,7 @@ class SequenceContainer:
 		 * @throw SequenceNotFoundException If the name does not match any sequence in
 		 * the container.
 		 */
-		virtual const Comments& getComments(const std::string& name) const throw (SequenceNotFoundException) = 0;
+		virtual const Comments& getComments(const std::string& name) const = 0;
 		
 		/**
 		 * @brief Set the comments of a particular sequence.
@@ -205,7 +205,7 @@ class SequenceContainer:
 		 * @throw SequenceNotFoundException If the name does not match any sequence in
 		 * the container.
 		 */
-		virtual void setComments(const std::string& name, const Comments& comments) throw (SequenceNotFoundException) = 0;
+		virtual void setComments(const std::string& name, const Comments& comments) = 0;
 		
 		/**
 		 * @brief Get the comments of this container.
@@ -261,7 +261,7 @@ class SequenceContainer:
      * @throw SequenceNotFoundException If no corresponding sequence is found in the container.
      * @throw IndexOutOfBoundsException If the element position is not valid.
      */
-    virtual int& valueAt(const std::string& sequenceName, size_t elementIndex) throw (SequenceNotFoundException, IndexOutOfBoundsException) = 0;
+    virtual int& valueAt(const std::string& sequenceName, size_t elementIndex) = 0;
 
     /**
      * @brief Element access function.
@@ -273,7 +273,7 @@ class SequenceContainer:
      * @throw SequenceNotFoundException If no corresponding sequence is found in the container.
      * @throw IndexOutOfBoundsException If the element position is not valid.
      */
-    virtual const int& valueAt(const std::string& sequenceName, size_t elementIndex) const throw (SequenceNotFoundException, IndexOutOfBoundsException) = 0;
+    virtual const int& valueAt(const std::string& sequenceName, size_t elementIndex) const = 0;
 
     /**
      * @brief Element access operator.
