@@ -81,24 +81,24 @@ class MoldMitochondrialGeneticCode:
       return v;
     }
    
-    bool isStop(int state) const throw (BadIntException) {
+    bool isStop(int state) const {
       //Test:
       codonAlphabet_.intToChar(state); //throw exception if invalid state!
       return (state == 48 || state == 50);
     }
     
-    bool isStop(const std::string& state) const throw (BadCharException) {
+    bool isStop(const std::string& state) const {
       int i = codonAlphabet_.charToInt(state);
       return (i == 48 || i == 50);
     }
  
-    bool isAltStart(int state) const throw (BadIntException) {
+    bool isAltStart(int state) const {
       //Test:
       codonAlphabet_.intToChar(state); //throw exception if invalid state!
       return (state == 12 || state == 13 || state == 15 || state == 30 || state == 46 || state == 60 || state == 62);
     }
     
-    bool isAltStart(const std::string& state) const throw (BadCharException) {
+    bool isAltStart(const std::string& state) const {
       int i = codonAlphabet_.charToInt(state);
       return (i == 12 || i == 13 || i == 15 || i == 30 || i == 46 || i == 60 || i == 62);
     }
