@@ -79,7 +79,7 @@ namespace bpp
      * @return A new OSequence object according to options specified.
      * @throw Exception if an error occured.
      */
-    OSequence* read(const std::string& description) throw (Exception);
+    OSequence* read(const std::string& description);
 
     /**
      * @return The arguments and their unparsed values from the last call of the read function, if there are any.
