@@ -78,7 +78,7 @@ class ISequence :
      * @return A new SequenceContainer object.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual SequenceContainer* readSequences(std::istream& input, const Alphabet* alpha) const throw (Exception) = 0;
+    virtual SequenceContainer* readSequences(std::istream& input, const Alphabet* alpha) const = 0;
     /**
      * @brief Create a new container from a file.
      *
@@ -87,7 +87,7 @@ class ISequence :
      * @return A new SequenceContainer object.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual SequenceContainer* readSequences(const std::string& path, const Alphabet* alpha) const throw (Exception) = 0;
+    virtual SequenceContainer* readSequences(const std::string& path, const Alphabet* alpha) const = 0;
 
 };
 
@@ -113,7 +113,7 @@ class IAlignment:
      * @return A new SiteContainer object.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual SiteContainer* readAlignment(std::istream& input, const Alphabet* alpha) const throw (Exception) = 0;
+    virtual SiteContainer* readAlignment(std::istream& input, const Alphabet* alpha) const = 0;
     /**
      * @brief Create a new container from a file.
      *
@@ -122,7 +122,7 @@ class IAlignment:
      * @return A new SiteContainer object.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual SiteContainer* readAlignment(const std::string& path, const Alphabet* alpha) const throw (Exception) = 0;
+    virtual SiteContainer* readAlignment(const std::string& path, const Alphabet* alpha) const = 0;
 
 };
 
